@@ -15,7 +15,7 @@ function (x, y, weights = rep(1, nobs), start = NULL, etastart = NULL,
   if (is.null(weights))   weights <- rep.int(1, nobs)
   if (is.null(offset))    offset <- rep.int(0, nobs)
   eval(family$initialize)
-  if (coefprior$family == "BIC") coefprior$hyper = nobs
+  if (coefprior$family == "BIC") coefprior$hyper = as.numeric(nobs)
   newfit = .Call("glm_fit",
     RX=x, RY = y,
     family=family, Roffset = offset,
